@@ -33,8 +33,8 @@ list_sizes_unnamed <- function(x) {
   unname(list_sizes(x))
 }
 
-expand_grid_col_major <- function(...) {
-  rev(tidyr::expand_grid(!!!rev(list2(...))))
+expand_grid_col_major <- function(x) {
+  rev(tidyr::expand_grid(!!!rev(x)))
 }
 
 set_intersect <- function(x, y) {
@@ -49,7 +49,7 @@ set_diff <- function(x, y) {
 }
 
 all_equal_dim_names <- function(target, current) {
-  if (all(names(target) == names(current))) {
+  if (identical(names(target), names(current))) {
     all(purrr::map2_lgl(target, current,
                         function(target, current) {
                           isTRUE(all.equal(target, current))
